@@ -149,7 +149,8 @@ class NN_degenerate(object):
                         i = i.strip().split(" ")
                         acc_id = i[0]
                     else:
-                        sequence = re.sub("[^ACGTRYMKSWHBVDN]", "-", i.strip().upper())
+                        # carefully !, make sure that Ns have been replaced!
+                        sequence = re.sub("[^ACGTRYMKSWHBVD]", "-", i.strip().upper())
                         seq_dict[acc_id] += sequence
         return seq_dict, len(seq_dict)
 
